@@ -1,14 +1,15 @@
 #! /usr/lib/veetest/veetest -r
-(revision "A.00.00")
-(date "Tue 02/Apr/1991")
-(component 0 "Context"
+(revision "B.00.00")
+(date "Mon 09/Nov/1992")
+(component 0 "ROOTCONTEXT"
  (name "Read/Write File Example")
  (interface
  )
  (implementation
-  (trigMode deg)
   (locked no)
-  (component 0 "TextDisplay"
+  (trigMode deg)
+  (nextID 15)
+  (component 0 "TEXTDISPLAY"
    (name "DATA FROM FILE")
    (interface
     (sequence out)
@@ -27,14 +28,31 @@
      (extent 136 25)
     )
     (detail
-     (origin 575 410)
+     (origin 575 390)
      (extent 210 40)
     )
     (active detail)
    )
   )
-  (component 1 "ShellEscape"
+  (component 1 "SHELLESCAPE"
    (name "sh -c \"rm Data File\"")
+   (description 15 4
+    This Execute Program is used to run a unix ksh
+    shell with the "rm" command on the default
+    file.  
+    
+    For the advanced student, remember that a unix
+    rm performs an "unlink" operation that removes
+    the directory entry with the filename but does
+    not actually delete the file until after all
+    processes have closed the file.  In this example,
+    the "rm" does the unlink, but the file is not
+    removed until "Post Run" that occurs when STOP
+    is executed.  You may want to place a From File
+    device _after_ this device to verify that data
+    can still be accessed even when the file has been
+    removed from the directory. 
+   )
    (interface
     (sequence in)
     (sequence out)
@@ -64,36 +82,19 @@
     (component deathWait "Yes")
    )
    (views
-    (description 15 5
-     This HP-UX Escape is used to run a unix ksh
-     shell with the "rm" command on the default
-     file.  
-     
-     For the advanced student, remember that a unix
-     rm performs an "unlink" operation that removes
-     the directory entry with the filename but does
-     not actually delete the file until after all
-     processes have closed the file.  In this example,
-     the "rm" does the unlink, but the file is not
-     removed until "Post Run" that occurs when STOP
-     is executed.  You may want to place a From File
-     device _after_ this device to verify that data
-     can still be accessed even when the file has been
-     removed from the directory. 
-    )
     (icon
-     (origin 465 648)
+     (origin 465 628)
      (extent 190 25)
     )
     (detail
-     (origin 500 542)
+     (origin 331 572)
      (extent 388 116)
     )
     (terminals on)
     (active icon)
    )
   )
-  (component 2 "ExitProcess"
+  (component 2 "EXITPROCESS"
    (name "Stop")
    (interface
     (sequence in)
@@ -103,7 +104,7 @@
    )
    (views
     (icon
-     (origin 537 688)
+     (origin 537 668)
      (extent 46 25)
     )
     (detail
@@ -113,7 +114,7 @@
     (active icon)
    )
   )
-  (component 3 "Delay"
+  (component 3 "DELAY"
    (name "0.5 Sec")
    (interface
     (sequence in)
@@ -124,7 +125,7 @@
    )
    (views
     (icon
-     (origin 711 638)
+     (origin 711 618)
      (extent 78 25)
     )
     (detail
@@ -134,8 +135,20 @@
     (active icon)
    )
   )
-  (component 4 "ToFile"
+  (component 4 "TOFILE"
    (name "Write new Data to File")
+   (description 10 4
+    This To File device first rewinds the file (sets
+    the output file pointer back to beginning of file),
+    then writes the new value to the file.
+    
+    The Write Mode, as set via the Clear File At 
+    PreRun & Open box, must Overwrite (box checked), 
+    since rewinding is not allowed in Append mode.  
+    Remember that all To File devices that write to 
+    the same file name will SHARE a common Write Mode 
+    selection; changing it for one changes it for all.
+   )
    (interface
     (sequence in)
     (sequence out)
@@ -159,32 +172,35 @@
     )
    )
    (views
-    (description 10 5
-     This To File device first rewinds the file (sets
-     the output file pointer back to beginning of file),
-     then writes the new value to the file.
-     
-     The Write Mode, as set from the Object Menu, must
-     be "OVERWRITE", since rewinding is not allowed in
-     Append mode.  Remember that all To File devices
-     that write to the same file name will SHARE a 
-     common Write Mode selection; changing it for one
-     changes it for all.
-    )
     (icon
      (origin 626 598)
      (extent 208 25)
     )
     (detail
-     (origin 620 518)
+     (origin 620 498)
      (extent 271 105)
     )
     (terminals on)
     (active detail)
    )
   )
-  (component 5 "ToFile"
+  (component 5 "TOFILE"
    (name "No, create defaultfile")
+   (description 13 4
+    If the file errors during rewind, we will assume
+    that it doesn't exist.  (To be extremely robust,
+    the error number should indicate "file not found",
+    since a few other errors could cause the rewind to
+    fail.)
+    
+    This ToFile writes an initial value to the file.
+    Although it doesn't matter whether the Write Mode
+    is Append or Overwrite when the file is first
+    created, remember that ALL ToFile devices with
+    the same file name will SHARE a common Write Mode!
+    (The file is in Overwrite mode when the Clear File
+    At PreRun & Open box is checked.)
+   )
    (interface
     (sequence in)
     (sequence out)
@@ -207,32 +223,19 @@
     )
    )
    (views
-    (description 11 5
-     If the file errors during rewind, we will assume
-     that it doesn't exist.  (To be extremely robust,
-     the error number should indicate "file not found",
-     since a few other errors could cause the rewind to
-     fail.)
-     
-     This ToFile writes an initial value to the file.
-     Although it doesn't matter whether the Write Mode
-     is Append or Overwrite when the file is first
-     created, remember that ALL ToFile devices with
-     the same file name will SHARE a common Write Mode!
-    )
     (icon
      (origin 486 288)
      (extent 208 25)
     )
     (detail
-     (origin 589 249)
+     (origin 589 229)
      (extent 273 103)
     )
     (terminals on)
     (active detail)
    )
   )
-  (component 6 "Formula"
+  (component 6 "FORMULA"
    (name " - ")
    (interface
     (sequence in)
@@ -259,7 +262,7 @@
    )
    (views
     (icon
-     (origin 367 608)
+     (origin 367 588)
      (extent 46 25)
     )
     (detail
@@ -268,7 +271,7 @@
     (active icon)
    )
   )
-  (component 7 "IfThenElse"
+  (component 7 "IFTHENELSE"
    (name "A >= 0")
    (interface
     (sequence in)
@@ -295,7 +298,7 @@
    )
    (views
     (icon
-     (origin 451 608)
+     (origin 451 588)
      (extent 78 25)
     )
     (detail
@@ -306,8 +309,28 @@
     (active icon)
    )
   )
-  (component 8 "FromFile"
+  (component 8 "FROMFILE"
    (name "Does File Exist?")
+   (description 18 4
+    The recommended way to determine if a file exists
+    is to REWIND it in a From File device.  If the
+    file does not exist, an error is generated. 
+    
+    For our application, we also want to insure that
+    the data in the file can be read.  The second
+    transaction reads one Real number into the "null"
+    variable.  (Null accepts and then discards all
+    data sent to it.)
+    
+    Why would a REWIND in a TO File not be a good way
+    to test for file existence?  Remember that a file
+    opened for Write can be in Append or Overwrite
+    mode, and Rewind is illegal in append.  (The file
+    is in Overwrite mode when the Clear File At PreRun
+    & Open box is checked.)  Also, opening a To File 
+    will create an empty file if one does not exist.
+    
+   )
    (interface
     (sequence in)
     (sequence out)
@@ -328,42 +351,23 @@
     )
     (procedure
       EXECUTE REWIND
-      READ TEXT null REAL COUNT:1
+      READ TEXT null REAL
     )
    )
    (views
-    (description 17 5
-     The recommended way to determine if a file exists
-     is to REWIND it in a From File device.  If the
-     file does not exist, an error is generated. 
-     
-     For our application, we also want to insure that
-     the data in the file can be read.  The second
-     transaction reads one Real number into the "null"
-     variable.  (Null accepts and then discards all
-     data sent to it.)
-     
-     Why would a REWIND in a TO File not be a good way
-     to test for file existence?  Remember that a file
-     opened for Write can be in Append or Overwrite
-     mode, and Rewind is illegal in append.  Also,
-     opening a To File will create an empty file if
-     one does not exist.
-     
-    )
     (icon
      (origin 93 348)
      (extent 154 25)
     )
     (detail
-     (origin 42 255)
+     (origin 42 235)
      (extent 287 90)
     )
     (terminals on)
     (active detail)
    )
   )
-  (component 9 "RepeatUntilBreak"
+  (component 9 "REPEATUNTILBREAK"
    (interface
     (sequence in)
     (sequence out)
@@ -377,9 +381,9 @@
    )
    (views
     (icon
-     (origin 145 368)
+     (origin 145 348)
      (extent 110 64)
-     (iconImage loop.icon)
+     (iconImage "loop.icon")
     )
     (detail
     )
@@ -387,8 +391,26 @@
     (active icon)
    )
   )
-  (component 10 "FromFile"
+  (component 10 "FROMFILE"
    (name "Read the data from file")
+   (description 16 4
+    Each time through the loop, we read the data that
+    was last written to the file.  We must always
+    REWIND the file before reading to insure the
+    READ transaction will not hit an EOF.
+    
+    IMPORTANT:  Rewinding the "read" file pointer will
+    rewind all From File devices with the same data
+    file name, since all share a common File pointer.
+    
+    However, this has no effect on a ToFile device
+    write file pointer for the same file name.  The
+    existence of two file pointers, one for reading
+    and one for writing, may seem strange, but it does
+    allow one thread to write ahead of another thread
+    that is reading and processing the data.
+    
+   )
    (interface
     (sequence in)
     (sequence out)
@@ -409,41 +431,23 @@
     )
     (procedure
       EXECUTE REWIND
-      READ TEXT x REAL COUNT:1
+      READ TEXT x REAL
     )
    )
    (views
-    (description 16 5
-     Each time through the loop, we read the data that
-     was last written to the file.  We must always
-     REWIND the file before reading to insure the
-     READ transaction will not hit an EOF.
-     
-     IMPORTANT:  Rewinding the "read" file pointer will
-     rewind all From File devices with the same data
-     file name, since all share a common File pointer.
-     
-     However, this has no effect on a ToFile device
-     write file pointer for the same file name.  The
-     existence of two file pointers, one for reading
-     and one for writing, may seem strange, but it does
-     allow one thread to write ahead of another thread
-     that is reading and processing the data.
-     
-    )
     (icon
      (origin 327 498)
      (extent 217 25)
     )
     (detail
-     (origin 107 473)
+     (origin 107 453)
      (extent 326 94)
     )
     (terminals on)
     (active detail)
    )
   )
-  (component 11 "Constant"
+  (component 11 "CONSTANT"
    (name "Amt to Deduct")
    (interface
     (sequence in)
@@ -462,6 +466,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Real
+     (name "Real")
      (datum 0)
     )
    )
@@ -471,13 +476,13 @@
      (extent 127 25)
     )
     (detail
-     (origin 80 616)
+     (origin 80 596)
      (extent 201 28)
     )
     (active detail)
    )
   )
-  (component 12 "Note"
+  (component 12 "NOTE"
    (name "Warranty Disclaimer")
    (interface
    )
@@ -494,14 +499,14 @@
      (extent 181 0)
     )
     (detail
-     (origin 570 118)
+     (origin 570 98)
      (extent 401 84)
      (editing disabled)
     )
     (active detail)
    )
   )
-  (component 13 "Note"
+  (component 13 "NOTE"
    (interface
    )
    (implementation
@@ -516,23 +521,24 @@
     (icon
     )
     (detail
-     (origin 347 120)
+     (origin 347 100)
      (extent 206 81)
      (editing disabled)
     )
     (active detail)
    )
   )
-  (component 14 "Context"
+  (component 14 "CONTEXT"
    (name "Press For")
    (interface
     (sequence in)
     (sequence out)
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "IfThenElse"
+    (trigMode deg)
+    (nextID 4)
+    (component 0 "IFTHENELSE"
      (name "If != 0")
      (interface
       (sequence in)
@@ -559,7 +565,7 @@
      )
      (views
       (icon
-       (origin 301 322)
+       (origin 301 332)
        (extent 78 25)
       )
       (detail
@@ -570,7 +576,7 @@
       (active icon)
      )
     )
-    (component 1 "Toggle"
+    (component 1 "TOGGLE"
      (name "Info About")
      (interface
       (sequence in)
@@ -596,12 +602,13 @@
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Int32
+       (name "LongInt")
        (datum 0)
       )
      )
      (views
       (icon
-       (origin 153 315)
+       (origin 153 325)
        (extent 114 39)
        (format button)
       )
@@ -613,7 +620,7 @@
       (active icon)
      )
     )
-    (component 2 "RepeatUntilBreak"
+    (component 2 "REPEATUNTILBREAK"
      (interface
       (sequence in)
       (sequence out)
@@ -627,9 +634,9 @@
      )
      (views
       (icon
-       (origin 75 238)
+       (origin 75 248)
        (extent 110 64)
-       (iconImage loop.icon)
+       (iconImage "loop.icon")
       )
       (detail
       )
@@ -637,16 +644,17 @@
       (active icon)
      )
     )
-    (component 3 "Context"
+    (component 3 "CONTEXT"
      (name "Info About This Example")
      (interface
       (sequence in)
       (sequence out)
      )
      (implementation
-      (trigMode deg)
       (locked no)
-      (component 0 "Confirm"
+      (trigMode deg)
+      (nextID 2)
+      (component 0 "CONFIRM"
        (name "DONE")
        (interface
         (sequence in)
@@ -661,7 +669,7 @@
        )
        (views
         (icon
-         (origin 310 409)
+         (origin 637 629)
          (extent 58 37)
         )
         (detail
@@ -672,12 +680,12 @@
         (active icon)
        )
       )
-      (component 1 "Note"
+      (component 1 "NOTE"
        (name "NotePad")
        (interface
        )
        (implementation
-        (component text 25 9
+        (component text 24 9
          PURPOSE:  Illustrate how to save data between successive executions of a program by
                    writing the latest data to a file after reading and modifying data previously
                    written to the same file.
@@ -700,20 +708,19 @@
                    data; 
          
                    These techniques are useful in cases where calibration data must be read and
-                   updated from a file, where "global" data must be saved between subsequent
-                   executions of a Vee program, or to allow one "thread" to write data to a
-                   file while another "thread" reads the data.
+                   updated from a file or where "global" data must be saved between subsequent
+                   executions of a Vee program.
         )
        )
        (views
         (icon
-         (origin 301 348)
+         (origin 628 568)
          (extent 78 25)
         )
         (detail
-         (origin 6 132)
+         (origin 16 146)
          (extent 848 437)
-         (editing disabled)
+         (editing enabled)
         )
         (active icon)
        )
@@ -722,19 +729,19 @@
       )
       (ShowOnExecPanel
        (origin 55 78)
-       (extent 849 571)
+       (extent 849 561)
        (panel
-        (origin 18 158)
+        (origin 18 168)
         (extent 845 533)
         (widget 1 detail
          (title off)
-         (origin 31 170)
+         (origin 31 180)
          (extent 816 465)
          (editing disabled)
         )
         (widget 0 icon
          (title off)
-         (origin 417 643)
+         (origin 417 653)
          (extent 58 37)
         )
        )
@@ -742,14 +749,15 @@
      )
      (views
       (icon
-       (origin 332 412)
+       (origin 332 422)
        (extent 217 25)
       )
       (detail
-       (origin 228 275)
+       (origin 228 309)
        (extent 405 230)
        (configuration
        )
+       (stackingOrder 0 1)
       )
       (active icon)
      )
@@ -763,15 +771,15 @@
    )
    (views
     (icon
-     (origin 175 368)
+     (origin 475 648)
      (extent 110 25)
     )
     (panel
-     (origin 11 122)
+     (origin 11 102)
      (extent 319 77)
      (widget 1 icon
       (title off)
-      (origin 113 135)
+      (origin 113 115)
       (extent 114 39)
       (format button)
      )
@@ -781,27 +789,28 @@
      (extent 912 591)
      (configuration
       (connect D1:1 D0:1
-       (Point 269 334)
-       (Point 298 334)
+       (Point 269 344)
+       (Point 298 344)
       )
       (connect D2:1 D1:0
-       (Point 187 270)
-       (Point 210 270)
-       (Point 210 312)
+       (Point 187 280)
+       (Point 210 280)
+       (Point 210 322)
       )
       (connect D3:0 D1:1
-       (Point 440 439)
-       (Point 440 460)
-       (Point 130 460)
-       (Point 130 334)
-       (Point 150 334)
+       (Point 440 449)
+       (Point 440 470)
+       (Point 130 470)
+       (Point 130 344)
+       (Point 150 344)
       )
       (connect D0:1 D3:0
-       (Point 381 324)
-       (Point 440 324)
-       (Point 440 409)
+       (Point 381 334)
+       (Point 440 334)
+       (Point 440 419)
       )
      )
+     (stackingOrder 0 1 2 3)
     )
     (active panel)
     (active panel)
@@ -824,76 +833,76 @@
  )
  (views
   (detail
-   (origin 0 67)
-   (extent 980 653)
+   (origin 0 62)
+   (extent 980 643)
    (configuration
     (connect D10:1 D0:1
-     (Point 465 520)
-     (Point 490 520)
-     (Point 490 430)
-     (Point 572 430)
+     (Point 465 500)
+     (Point 490 500)
+     (Point 490 410)
+     (Point 572 410)
     )
     (connect D7:2 D1:0
-     (Point 531 630)
-     (Point 560 630)
-     (Point 560 645)
+     (Point 531 610)
+     (Point 560 610)
+     (Point 560 625)
     )
     (connect D1:0 D2:0
-     (Point 560 675)
-     (Point 560 685)
+     (Point 560 655)
+     (Point 560 665)
     )
     (connect D4:0 D3:0
-     (Point 750 625)
-     (Point 750 635)
+     (Point 750 605)
+     (Point 750 615)
     )
     (connect D7:1 D4:0
-     (Point 531 610)
-     (Point 550 610)
-     (Point 550 470)
-     (Point 750 470)
-     (Point 750 485)
+     (Point 531 590)
+     (Point 550 590)
+     (Point 550 450)
+     (Point 750 450)
+     (Point 750 467)
     )
     (connect D6:1 D4:1
-     (Point 415 620)
-     (Point 430 620)
+     (Point 415 600)
      (Point 430 600)
-     (Point 490 600)
-     (Point 490 570)
-     (Point 577 570)
+     (Point 430 580)
+     (Point 490 580)
+     (Point 490 550)
+     (Point 577 550)
     )
     (connect D8:1 D5:1
-     (Point 391 300)
-     (Point 546 300)
+     (Point 391 280)
+     (Point 546 280)
     )
     (connect D10:1 D6:1
-     (Point 465 520)
-     (Point 490 520)
-     (Point 490 560)
-     (Point 480 560)
-     (Point 480 590)
+     (Point 465 500)
+     (Point 490 500)
+     (Point 490 540)
+     (Point 480 540)
+     (Point 480 570)
+     (Point 364 570)
      (Point 364 590)
-     (Point 364 610)
     )
     (connect D11:1 D6:2
-     (Point 283 630)
-     (Point 364 630)
+     (Point 283 610)
+     (Point 364 610)
     )
     (connect D6:1 D7:1
-     (Point 415 620)
-     (Point 431 620)
-     (Point 431 620)
-     (Point 448 620)
+     (Point 415 600)
+     (Point 448 600)
     )
     (connect D8:0 D9:0
-     (Point 200 347)
-     (Point 200 365)
+     (Point 200 327)
+     (Point 200 345)
     )
     (connect D9:1 D10:0
-     (Point 257 400)
-     (Point 270 400)
-     (Point 270 440)
+     (Point 257 380)
+     (Point 270 380)
+     (Point 270 422)
     )
    )
+   (stackingOrder 0 2 4 5 6 7 8 10 11 12
+     13 9 1 14 3)
   )
   (active detail)
   (numberFormats
