@@ -1,14 +1,15 @@
 #! /usr/lib/veetest/veetest -r
-(revision "A.00.01")
-(date "Mon 16/Sep/1991")
-(component 0 "Context"
+(revision "B.00.00")
+(date "Mon 09/Nov/1992")
+(component 0 "ROOTCONTEXT"
  (name "The Mole Game")
  (interface
  )
  (implementation
-  (trigMode deg)
   (locked no)
-  (component 0 "Context"
+  (trigMode deg)
+  (nextID 28)
+  (component 0 "CONTEXT"
    (name "I\'m a mole")
    (interface
     (sequence in)
@@ -36,9 +37,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Delay"
+    (trigMode deg)
+    (nextID 4)
+    (component 0 "DELAY"
      (interface
       (sequence in)
       (sequence out)
@@ -52,6 +54,7 @@
        )
        (lock constraints)
        (optional yes)
+       (buffer YES)
       )
       (output 1
        (type data)
@@ -59,9 +62,6 @@
        (tag "Done")
        (lock constraints)
       )
-      (buffers in
-       (buffer "Delay")
-      )
      )
      (implementation
       (component delay 1.5)
@@ -76,7 +76,7 @@
       (active detail)
      )
     )
-    (component 1 "ExitContext"
+    (component 1 "EXITCONTEXT"
      (interface
       (sequence in)
      )
@@ -93,7 +93,7 @@
       (active icon)
      )
     )
-    (component 2 "Confirm"
+    (component 2 "CONFIRM"
      (name "Hit Me!")
      (interface
       (sequence in)
@@ -119,7 +119,7 @@
       (active icon)
      )
     )
-    (component 3 "Escape"
+    (component 3 "ESCAPE"
      (interface
       (sequence in)
      )
@@ -145,7 +145,7 @@
     )
     (ShowOnExecPanel
      (origin 95 360)
-     (extent 97 83)
+     (extent 97 73)
      (panel
       (origin 544 158)
       (extent 93 45)
@@ -159,7 +159,7 @@
    )
    (views
     (icon
-     (origin 545 338)
+     (origin 545 333)
      (extent 110 25)
     )
     (detail
@@ -185,19 +185,20 @@
        (Point 630 260)
        (Point 630 290)
        (Point 570 290)
-       (Point 570 306)
+       (Point 570 308)
       )
       (connect D0:1 O1:1
        (Point 787 250)
        (Point 832 250)
       )
      )
+     (stackingOrder 0 1 2 3)
     )
     (terminals on)
     (active icon)
    )
   )
-  (component 1 "Context"
+  (component 1 "CONTEXT"
    (name "I\'m a mole")
    (interface
     (sequence in)
@@ -225,9 +226,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Delay"
+    (trigMode deg)
+    (nextID 4)
+    (component 0 "DELAY"
      (interface
       (sequence in)
       (sequence out)
@@ -241,6 +243,7 @@
        )
        (lock constraints)
        (optional yes)
+       (buffer YES)
       )
       (output 1
        (type data)
@@ -248,9 +251,6 @@
        (tag "Done")
        (lock constraints)
       )
-      (buffers in
-       (buffer "Delay")
-      )
      )
      (implementation
       (component delay 1.5)
@@ -265,7 +265,7 @@
       (active detail)
      )
     )
-    (component 1 "ExitContext"
+    (component 1 "EXITCONTEXT"
      (interface
       (sequence in)
      )
@@ -282,7 +282,7 @@
       (active icon)
      )
     )
-    (component 2 "Confirm"
+    (component 2 "CONFIRM"
      (name "Hit Me!")
      (interface
       (sequence in)
@@ -308,7 +308,7 @@
       (active icon)
      )
     )
-    (component 3 "Escape"
+    (component 3 "ESCAPE"
      (interface
       (sequence in)
      )
@@ -334,7 +334,7 @@
     )
     (ShowOnExecPanel
      (origin 412 301)
-     (extent 97 83)
+     (extent 97 73)
      (panel
       (origin 544 158)
       (extent 93 45)
@@ -348,7 +348,7 @@
    )
    (views
     (icon
-     (origin 545 378)
+     (origin 545 373)
      (extent 110 25)
     )
     (detail
@@ -374,19 +374,20 @@
        (Point 630 260)
        (Point 630 290)
        (Point 570 290)
-       (Point 570 306)
+       (Point 570 308)
       )
       (connect D0:1 O1:1
        (Point 787 250)
        (Point 832 250)
       )
      )
+     (stackingOrder 0 1 2 3)
     )
     (terminals on)
     (active icon)
    )
   )
-  (component 2 "Context"
+  (component 2 "CONTEXT"
    (name "I\'m a mole")
    (interface
     (sequence in)
@@ -414,9 +415,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Delay"
+    (trigMode deg)
+    (nextID 4)
+    (component 0 "DELAY"
      (interface
       (sequence in)
       (sequence out)
@@ -430,6 +432,7 @@
        )
        (lock constraints)
        (optional yes)
+       (buffer YES)
       )
       (output 1
        (type data)
@@ -437,9 +440,6 @@
        (tag "Done")
        (lock constraints)
       )
-      (buffers in
-       (buffer "Delay")
-      )
      )
      (implementation
       (component delay 1.5)
@@ -454,7 +454,7 @@
       (active detail)
      )
     )
-    (component 1 "ExitContext"
+    (component 1 "EXITCONTEXT"
      (interface
       (sequence in)
      )
@@ -471,7 +471,7 @@
       (active icon)
      )
     )
-    (component 2 "Confirm"
+    (component 2 "CONFIRM"
      (name "Hit Me!")
      (interface
       (sequence in)
@@ -497,7 +497,7 @@
       (active icon)
      )
     )
-    (component 3 "Escape"
+    (component 3 "ESCAPE"
      (interface
       (sequence in)
      )
@@ -523,7 +523,7 @@
     )
     (ShowOnExecPanel
      (origin 371 461)
-     (extent 97 83)
+     (extent 97 73)
      (panel
       (origin 544 158)
       (extent 93 45)
@@ -537,7 +537,7 @@
    )
    (views
     (icon
-     (origin 545 618)
+     (origin 545 613)
      (extent 110 25)
     )
     (detail
@@ -563,19 +563,20 @@
        (Point 630 260)
        (Point 630 290)
        (Point 570 290)
-       (Point 570 306)
+       (Point 570 308)
       )
       (connect D0:1 O1:1
        (Point 787 250)
        (Point 832 250)
       )
      )
+     (stackingOrder 0 1 2 3)
     )
     (terminals on)
     (active icon)
    )
   )
-  (component 3 "Context"
+  (component 3 "CONTEXT"
    (name "I\'m a mole")
    (interface
     (sequence in)
@@ -603,9 +604,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Delay"
+    (trigMode deg)
+    (nextID 4)
+    (component 0 "DELAY"
      (interface
       (sequence in)
       (sequence out)
@@ -619,6 +621,7 @@
        )
        (lock constraints)
        (optional yes)
+       (buffer YES)
       )
       (output 1
        (type data)
@@ -626,9 +629,6 @@
        (tag "Done")
        (lock constraints)
       )
-      (buffers in
-       (buffer "Delay")
-      )
      )
      (implementation
       (component delay 1.5)
@@ -643,7 +643,7 @@
       (active detail)
      )
     )
-    (component 1 "ExitContext"
+    (component 1 "EXITCONTEXT"
      (interface
       (sequence in)
      )
@@ -660,7 +660,7 @@
       (active icon)
      )
     )
-    (component 2 "Confirm"
+    (component 2 "CONFIRM"
      (name "Hit Me!")
      (interface
       (sequence in)
@@ -686,7 +686,7 @@
       (active icon)
      )
     )
-    (component 3 "Escape"
+    (component 3 "ESCAPE"
      (interface
       (sequence in)
      )
@@ -712,7 +712,7 @@
     )
     (ShowOnExecPanel
      (origin 277 242)
-     (extent 97 83)
+     (extent 97 73)
      (panel
       (origin 544 158)
       (extent 93 45)
@@ -726,7 +726,7 @@
    )
    (views
     (icon
-     (origin 545 578)
+     (origin 545 573)
      (extent 110 25)
     )
     (detail
@@ -752,19 +752,20 @@
        (Point 630 260)
        (Point 630 290)
        (Point 570 290)
-       (Point 570 306)
+       (Point 570 308)
       )
       (connect D0:1 O1:1
        (Point 787 250)
        (Point 832 250)
       )
      )
+     (stackingOrder 0 1 2 3)
     )
     (terminals on)
     (active icon)
    )
   )
-  (component 4 "Context"
+  (component 4 "CONTEXT"
    (name "I\'m a mole")
    (interface
     (sequence in)
@@ -792,9 +793,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Delay"
+    (trigMode deg)
+    (nextID 4)
+    (component 0 "DELAY"
      (interface
       (sequence in)
       (sequence out)
@@ -808,6 +810,7 @@
        )
        (lock constraints)
        (optional yes)
+       (buffer YES)
       )
       (output 1
        (type data)
@@ -815,9 +818,6 @@
        (tag "Done")
        (lock constraints)
       )
-      (buffers in
-       (buffer "Delay")
-      )
      )
      (implementation
       (component delay 1.5)
@@ -832,7 +832,7 @@
       (active detail)
      )
     )
-    (component 1 "ExitContext"
+    (component 1 "EXITCONTEXT"
      (interface
       (sequence in)
      )
@@ -849,7 +849,7 @@
       (active icon)
      )
     )
-    (component 2 "Confirm"
+    (component 2 "CONFIRM"
      (name "Hit Me!")
      (interface
       (sequence in)
@@ -875,7 +875,7 @@
       (active icon)
      )
     )
-    (component 3 "Escape"
+    (component 3 "ESCAPE"
      (interface
       (sequence in)
      )
@@ -901,7 +901,7 @@
     )
     (ShowOnExecPanel
      (origin 530 405)
-     (extent 97 83)
+     (extent 97 73)
      (panel
       (origin 544 158)
       (extent 93 45)
@@ -915,7 +915,7 @@
    )
    (views
     (icon
-     (origin 545 538)
+     (origin 545 533)
      (extent 110 25)
     )
     (detail
@@ -941,19 +941,20 @@
        (Point 630 260)
        (Point 630 290)
        (Point 570 290)
-       (Point 570 306)
+       (Point 570 308)
       )
       (connect D0:1 O1:1
        (Point 787 250)
        (Point 832 250)
       )
      )
+     (stackingOrder 0 1 2 3)
     )
     (terminals on)
     (active icon)
    )
   )
-  (component 5 "Context"
+  (component 5 "CONTEXT"
    (name "I\'m a mole")
    (interface
     (sequence in)
@@ -981,9 +982,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Delay"
+    (trigMode deg)
+    (nextID 4)
+    (component 0 "DELAY"
      (interface
       (sequence in)
       (sequence out)
@@ -997,6 +999,7 @@
        )
        (lock constraints)
        (optional yes)
+       (buffer YES)
       )
       (output 1
        (type data)
@@ -1004,9 +1007,6 @@
        (tag "Done")
        (lock constraints)
       )
-      (buffers in
-       (buffer "Delay")
-      )
      )
      (implementation
       (component delay 1.5)
@@ -1021,7 +1021,7 @@
       (active detail)
      )
     )
-    (component 1 "ExitContext"
+    (component 1 "EXITCONTEXT"
      (interface
       (sequence in)
      )
@@ -1038,7 +1038,7 @@
       (active icon)
      )
     )
-    (component 2 "Confirm"
+    (component 2 "CONFIRM"
      (name "Hit Me!")
      (interface
       (sequence in)
@@ -1064,7 +1064,7 @@
       (active icon)
      )
     )
-    (component 3 "Escape"
+    (component 3 "ESCAPE"
      (interface
       (sequence in)
      )
@@ -1090,7 +1090,7 @@
     )
     (ShowOnExecPanel
      (origin 692 262)
-     (extent 97 83)
+     (extent 97 73)
      (panel
       (origin 544 158)
       (extent 93 45)
@@ -1104,7 +1104,7 @@
    )
    (views
     (icon
-     (origin 545 418)
+     (origin 545 413)
      (extent 110 25)
     )
     (detail
@@ -1130,19 +1130,20 @@
        (Point 630 260)
        (Point 630 290)
        (Point 570 290)
-       (Point 570 306)
+       (Point 570 308)
       )
       (connect D0:1 O1:1
        (Point 787 250)
        (Point 832 250)
       )
      )
+     (stackingOrder 0 1 2 3)
     )
     (terminals on)
     (active icon)
    )
   )
-  (component 6 "Context"
+  (component 6 "CONTEXT"
    (name "I\'m a mole")
    (interface
     (sequence in)
@@ -1170,9 +1171,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Delay"
+    (trigMode deg)
+    (nextID 4)
+    (component 0 "DELAY"
      (interface
       (sequence in)
       (sequence out)
@@ -1186,6 +1188,7 @@
        )
        (lock constraints)
        (optional yes)
+       (buffer YES)
       )
       (output 1
        (type data)
@@ -1193,9 +1196,6 @@
        (tag "Done")
        (lock constraints)
       )
-      (buffers in
-       (buffer "Delay")
-      )
      )
      (implementation
       (component delay 1.5)
@@ -1210,7 +1210,7 @@
       (active detail)
      )
     )
-    (component 1 "ExitContext"
+    (component 1 "EXITCONTEXT"
      (interface
       (sequence in)
      )
@@ -1227,7 +1227,7 @@
       (active icon)
      )
     )
-    (component 2 "Confirm"
+    (component 2 "CONFIRM"
      (name "Hit Me!")
      (interface
       (sequence in)
@@ -1253,7 +1253,7 @@
       (active icon)
      )
     )
-    (component 3 "Escape"
+    (component 3 "ESCAPE"
      (interface
       (sequence in)
      )
@@ -1279,7 +1279,7 @@
     )
     (ShowOnExecPanel
      (origin 585 436)
-     (extent 97 83)
+     (extent 97 73)
      (panel
       (origin 544 158)
       (extent 93 45)
@@ -1293,7 +1293,7 @@
    )
    (views
     (icon
-     (origin 545 458)
+     (origin 545 453)
      (extent 110 25)
     )
     (detail
@@ -1319,19 +1319,20 @@
        (Point 630 260)
        (Point 630 290)
        (Point 570 290)
-       (Point 570 306)
+       (Point 570 308)
       )
       (connect D0:1 O1:1
        (Point 787 250)
        (Point 832 250)
       )
      )
+     (stackingOrder 0 1 2 3)
     )
     (terminals on)
     (active icon)
    )
   )
-  (component 7 "Context"
+  (component 7 "CONTEXT"
    (name "I\'m a mole")
    (interface
     (sequence in)
@@ -1359,9 +1360,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Delay"
+    (trigMode deg)
+    (nextID 4)
+    (component 0 "DELAY"
      (interface
       (sequence in)
       (sequence out)
@@ -1375,6 +1377,7 @@
        )
        (lock constraints)
        (optional yes)
+       (buffer YES)
       )
       (output 1
        (type data)
@@ -1382,9 +1385,6 @@
        (tag "Done")
        (lock constraints)
       )
-      (buffers in
-       (buffer "Delay")
-      )
      )
      (implementation
       (component delay 1.5)
@@ -1399,7 +1399,7 @@
       (active detail)
      )
     )
-    (component 1 "ExitContext"
+    (component 1 "EXITCONTEXT"
      (interface
       (sequence in)
      )
@@ -1416,7 +1416,7 @@
       (active icon)
      )
     )
-    (component 2 "Confirm"
+    (component 2 "CONFIRM"
      (name "Hit Me!")
      (interface
       (sequence in)
@@ -1442,7 +1442,7 @@
       (active icon)
      )
     )
-    (component 3 "Escape"
+    (component 3 "ESCAPE"
      (interface
       (sequence in)
      )
@@ -1468,7 +1468,7 @@
     )
     (ShowOnExecPanel
      (origin 758 415)
-     (extent 97 83)
+     (extent 97 73)
      (panel
       (origin 544 158)
       (extent 93 45)
@@ -1482,7 +1482,7 @@
    )
    (views
     (icon
-     (origin 545 498)
+     (origin 545 493)
      (extent 110 25)
     )
     (detail
@@ -1508,19 +1508,20 @@
        (Point 630 260)
        (Point 630 290)
        (Point 570 290)
-       (Point 570 306)
+       (Point 570 308)
       )
       (connect D0:1 O1:1
        (Point 787 250)
        (Point 832 250)
       )
      )
+     (stackingOrder 0 1 2 3)
     )
     (terminals on)
     (active icon)
    )
   )
-  (component 8 "Context"
+  (component 8 "CONTEXT"
    (name "I\'m a mole")
    (interface
     (sequence in)
@@ -1548,9 +1549,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Delay"
+    (trigMode deg)
+    (nextID 4)
+    (component 0 "DELAY"
      (interface
       (sequence in)
       (sequence out)
@@ -1564,6 +1566,7 @@
        )
        (lock constraints)
        (optional yes)
+       (buffer YES)
       )
       (output 1
        (type data)
@@ -1571,9 +1574,6 @@
        (tag "Done")
        (lock constraints)
       )
-      (buffers in
-       (buffer "Delay")
-      )
      )
      (implementation
       (component delay 1.5)
@@ -1588,7 +1588,7 @@
       (active detail)
      )
     )
-    (component 1 "ExitContext"
+    (component 1 "EXITCONTEXT"
      (interface
       (sequence in)
      )
@@ -1605,7 +1605,7 @@
       (active icon)
      )
     )
-    (component 2 "Confirm"
+    (component 2 "CONFIRM"
      (name "Hit Me!")
      (interface
       (sequence in)
@@ -1631,7 +1631,7 @@
       (active icon)
      )
     )
-    (component 3 "Escape"
+    (component 3 "ESCAPE"
      (interface
       (sequence in)
      )
@@ -1657,7 +1657,7 @@
     )
     (ShowOnExecPanel
      (origin 62 244)
-     (extent 97 83)
+     (extent 97 73)
      (panel
       (origin 544 158)
       (extent 93 45)
@@ -1671,7 +1671,7 @@
    )
    (views
     (icon
-     (origin 545 298)
+     (origin 545 293)
      (extent 110 25)
     )
     (detail
@@ -1697,19 +1697,20 @@
        (Point 580 190)
        (Point 580 220)
        (Point 520 220)
-       (Point 520 236)
+       (Point 520 238)
       )
       (connect D0:1 O1:1
        (Point 737 180)
        (Point 782 180)
       )
      )
+     (stackingOrder 0 1 2 3)
     )
     (terminals on)
     (active icon)
    )
   )
-  (component 9 "Confirm"
+  (component 9 "CONFIRM"
    (name "Stop")
    (interface
     (sequence in)
@@ -1730,7 +1731,7 @@
    )
    (views
     (icon
-     (origin 21 362)
+     (origin 21 357)
      (extent 58 37)
     )
     (detail
@@ -1741,7 +1742,7 @@
     (active icon)
    )
   )
-  (component 10 "Counter"
+  (component 10 "COUNTER"
    (name "Misses")
    (interface
     (sequence in)
@@ -1766,13 +1767,13 @@
      (extent 78 0)
     )
     (detail
-     (origin 855 253)
+     (origin 855 248)
      (extent 150 34)
     )
     (active detail)
    )
   )
-  (component 11 "Toggle"
+  (component 11 "TOGGLE"
    (name "show oops")
    (interface
     (sequence in)
@@ -1793,12 +1794,13 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Int32
+     (name "LongInt")
      (datum 0)
     )
    )
    (views
     (icon
-     (origin 861 307)
+     (origin 861 302)
      (extent 138 27)
      (format check box)
     )
@@ -1810,7 +1812,7 @@
     (active icon)
    )
   )
-  (component 12 "IfThenElse"
+  (component 12 "IFTHENELSE"
    (interface
     (sequence in)
     (sequence out)
@@ -1836,7 +1838,7 @@
    )
    (views
     (icon
-     (origin 891 368)
+     (origin 891 363)
      (extent 78 25)
     )
     (detail
@@ -1847,16 +1849,17 @@
     (active icon)
    )
   )
-  (component 13 "Context"
+  (component 13 "CONTEXT"
    (name "Oops...")
    (interface
     (sequence in)
     (sequence out)
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "LiteralConstant"
+    (trigMode deg)
+    (nextID 3)
+    (component 0 "LITERALCONSTANT"
      (interface
       (sequence in)
       (sequence out)
@@ -1875,6 +1878,7 @@
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Text
+       (name "CString")
        (datum "")
       )
      )
@@ -1888,7 +1892,7 @@
       (active detail)
      )
     )
-    (component 1 "Delay"
+    (component 1 "DELAY"
      (interface
       (sequence in)
       (sequence out)
@@ -1912,7 +1916,7 @@
       (active detail)
      )
     )
-    (component 2 "TextDisplay"
+    (component 2 "TEXTDISPLAY"
      (interface
       (sequence in)
       (sequence out)
@@ -1941,7 +1945,7 @@
     )
     (ShowOnExecPanel
      (origin 331 267)
-     (extent 209 79)
+     (extent 209 69)
      (panel
       (origin 578 350)
       (extent 205 41)
@@ -1955,7 +1959,7 @@
    )
    (views
     (icon
-     (origin 891 428)
+     (origin 891 423)
      (extent 78 25)
     )
     (detail
@@ -1966,7 +1970,7 @@
        (Point 450 671)
        (Point 450 680)
        (Point 460 680)
-       (Point 460 690)
+       (Point 460 692)
       )
       (connect D0:1 D2:1
        (Point 518 540)
@@ -1977,11 +1981,12 @@
        (Point 352 650)
       )
      )
+     (stackingOrder 0 1 2)
     )
     (active icon)
    )
   )
-  (component 14 "Junction"
+  (component 14 "JUNCTION"
    (name "JCT")
    (interface
     (input 1
@@ -2039,7 +2044,7 @@
    )
    (views
     (icon
-     (origin 787 223)
+     (origin 787 218)
      (extent 46 94)
     )
     (detail
@@ -2048,7 +2053,7 @@
     (active icon)
    )
   )
-  (component 15 "Junction"
+  (component 15 "JUNCTION"
    (name "JCT")
    (interface
     (input 1
@@ -2106,7 +2111,7 @@
    )
    (views
     (icon
-     (origin 797 573)
+     (origin 797 568)
      (extent 46 94)
     )
     (detail
@@ -2115,7 +2120,7 @@
     (active icon)
    )
   )
-  (component 16 "Counter"
+  (component 16 "COUNTER"
    (name "Hits")
    (interface
     (sequence in)
@@ -2140,13 +2145,13 @@
      (extent 46 0)
     )
     (detail
-     (origin 865 603)
+     (origin 865 598)
      (extent 150 34)
     )
     (active detail)
    )
   )
-  (component 17 "Start"
+  (component 17 "START"
    (interface
     (sequence out)
    )
@@ -2154,7 +2159,7 @@
    )
    (views
     (icon
-     (origin 17 192)
+     (origin 77 82)
      (extent 67 37)
     )
     (detail
@@ -2163,7 +2168,7 @@
     (active icon)
    )
   )
-  (component 18 "ForCount"
+  (component 18 "FORCOUNT"
    (interface
     (sequence in)
     (sequence out)
@@ -2178,7 +2183,7 @@
    )
    (views
     (icon
-     (origin 65 268)
+     (origin 65 263)
      (extent 110 64)
      (iconImage "loop.icon")
     )
@@ -2189,7 +2194,7 @@
     (active icon)
    )
   )
-  (component 19 "Note"
+  (component 19 "NOTE"
    (name "Warranty Disclaimer")
    (interface
    )
@@ -2198,23 +2203,24 @@
      This example is provided as an
      illustration "as is", and Hewlett-
      Packard Company makes no warranty
-     of any kindwith regard to this
+     of any kind with regard to this
      example.
     )
    )
    (views
     (icon
-     (extent 181 0)
+     (origin 190 153)
+     (extent 181 25)
     )
     (detail
-     (origin 115 121)
+     (origin 285 111)
      (extent 330 99)
      (editing disabled)
     )
     (active detail)
    )
   )
-  (component 20 "EnumConstant"
+  (component 20 "ENUMCONSTANT"
    (name "Skill Level")
    (interface
     (sequence in)
@@ -2239,6 +2245,7 @@
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
     (component initValue Enum
+     (name "Enum")
      (shared yes)
      (datum "Beginner")
     )
@@ -2248,14 +2255,14 @@
      (extent 110 0)
     )
     (detail
-     (origin 19 540)
+     (origin 19 535)
      (extent 182 81)
      (format buttons)
     )
     (active detail)
    )
   )
-  (component 21 "ExitProcess"
+  (component 21 "EXITPROCESS"
    (interface
     (sequence in)
    )
@@ -2264,7 +2271,7 @@
    )
    (views
     (icon
-     (origin 11 428)
+     (origin 11 423)
      (extent 78 64)
      (iconImage "stop.icon")
     )
@@ -2275,7 +2282,7 @@
     (active icon)
    )
   )
-  (component 22 "Formula"
+  (component 22 "FORMULA"
    (name "delay time")
    (interface
     (sequence in)
@@ -2297,7 +2304,7 @@
    )
    (views
     (icon
-     (origin 135 378)
+     (origin 135 373)
      (extent 110 64)
      (iconImage "formula.icon")
     )
@@ -2309,7 +2316,7 @@
     (active icon)
    )
   )
-  (component 23 "DeMultiplexer"
+  (component 23 "DEMULTIPLEXER"
    (interface
     (sequence in)
     (sequence out)
@@ -2390,14 +2397,14 @@
      (extent 127 25)
     )
     (detail
-     (origin 330 338)
+     (origin 330 333)
      (extent 70 304)
     )
     (terminals on)
     (active detail)
    )
   )
-  (component 24 "RandomNumber"
+  (component 24 "RANDOMNUMBER"
    (interface
     (sequence in)
     (sequence out)
@@ -2413,7 +2420,7 @@
    )
    (views
     (icon
-     (origin 47 638)
+     (origin 47 633)
      (extent 127 25)
     )
     (detail
@@ -2424,16 +2431,17 @@
     (active icon)
    )
   )
-  (component 25 "Context"
+  (component 25 "CONTEXT"
    (name "Press For")
    (interface
     (sequence in)
     (sequence out)
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "IfThenElse"
+    (trigMode deg)
+    (nextID 3)
+    (component 0 "IFTHENELSE"
      (name "!= 0")
      (interface
       (sequence in)
@@ -2471,7 +2479,7 @@
       (active icon)
      )
     )
-    (component 1 "Toggle"
+    (component 1 "TOGGLE"
      (name "Info About")
      (interface
       (sequence in)
@@ -2497,6 +2505,7 @@
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Int32
+       (name "LongInt")
        (datum 0)
       )
      )
@@ -2514,16 +2523,17 @@
       (active icon)
      )
     )
-    (component 2 "Context"
+    (component 2 "CONTEXT"
      (name "Info About This Example")
      (interface
       (sequence in)
       (sequence out)
      )
      (implementation
-      (trigMode deg)
       (locked no)
-      (component 0 "Confirm"
+      (trigMode deg)
+      (nextID 2)
+      (component 0 "CONFIRM"
        (name "DONE")
        (description 7 8
         This tiny "thread" begins running when the 
@@ -2558,7 +2568,7 @@
         (active icon)
        )
       )
-      (component 1 "Note"
+      (component 1 "NOTE"
        (name "NotePad")
        (description 2 8
         This notepad is displayed as a Show on Execute
@@ -2607,7 +2617,7 @@
       )
       (ShowOnExecPanel
        (origin 48 78)
-       (extent 849 571)
+       (extent 849 561)
        (panel
         (origin 88 164)
         (extent 845 533)
@@ -2635,6 +2645,7 @@
        (extent 866 520)
        (configuration
        )
+       (stackingOrder 0 1)
       )
       (active icon)
      )
@@ -2651,11 +2662,11 @@
      (extent 110 25)
     )
     (panel
-     (origin 465 118)
+     (origin 695 108)
      (extent 291 65)
      (widget 1 icon
       (title off)
-      (origin 552 129)
+      (origin 782 119)
       (extent 114 39)
       (format button)
      )
@@ -2681,11 +2692,67 @@
        (Point 510 415)
       )
      )
+     (stackingOrder 0 1 2)
     )
     (active panel)
     (active panel)
    )
   )
+  (component 26 "FORMULA"
+   (name "Get the time")
+   (interface
+    (sequence in)
+    (sequence out)
+    (output 1
+     (type data)
+     (name "Result")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked no)
+    (component expr 1 "now() MOD (2^31)")
+   )
+   (views
+    (icon
+     (origin 51 148)
+     (extent 118 25)
+    )
+    (detail
+     (origin 81 169)
+     (extent 178 62)
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 27 "RANDOMNUMBERSEED"
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Seed")
+     (requires
+      (datatype Int32)
+      (shape "Scalar")
+     )
+     (lock name constraints)
+    )
+   )
+   (implementation
+   )
+   (views
+    (icon
+     (origin 65 198)
+     (extent 110 25)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
   (configuration
    (connect D23:2 D0:1)
    (connect D23:3 D1:1)
@@ -2696,7 +2763,7 @@
    (connect D23:5 D6:1)
    (connect D23:6 D7:1)
    (connect D23:1 D8:1)
-   (connect D17:0 D9:0)
+   (connect D27:0 D9:0)
    (connect D18:0 D9:1)
    (connect D14:1 D10:1)
    (connect D10:0 D11:0)
@@ -2721,337 +2788,350 @@
    (connect D3:2 D15:8)
    (connect D2:2 D15:9)
    (connect D15:1 D16:1)
-   (connect D17:0 D18:0)
+   (connect D27:0 D18:0)
    (connect D18:1 D20:0)
    (connect D9:1 D21:0)
    (connect D20:1 D22:1)
    (connect D22:1 D23:1)
    (connect D24:1 D23:2)
    (connect D20:0 D24:0)
+   (connect D17:0 D26:0)
+   (connect D26:1 D27:1)
   )
  )
  (views
   (panel
-   (origin 0 67)
+   (origin 0 62)
    (extent 878 502)
    (widget 16 detail
     (title on)
-    (origin 361 111)
+    (origin 361 106)
     (extent 150 34)
    )
    (widget 10 detail
     (title on)
-    (origin 361 184)
+    (origin 361 179)
     (extent 150 34)
    )
    (widget 20 detail
     (title on)
-    (origin 185 112)
+    (origin 185 107)
     (extent 151 106)
     (format buttons)
    )
    (widget 11 icon
     (title off)
-    (origin 23 182)
+    (origin 23 177)
     (extent 138 37)
     (format button)
    )
    (widget 9 icon
     (title off)
-    (origin 23 129)
+    (origin 23 124)
     (extent 136 35)
    )
    (widget 17 icon
     (title off)
-    (origin 22 79)
+    (origin 22 74)
     (extent 139 35)
    )
    (widget 19 detail
     (title on)
-    (origin 540 111)
+    (origin 540 106)
     (extent 320 106)
     (editing disabled)
    )
   )
   (detail
-   (origin 0 67)
+   (origin 0 62)
    (extent 1004 664)
    (configuration
     (connect D23:2 D0:1
-     (Point 472 400)
-     (Point 480 400)
-     (Point 480 380)
-     (Point 490 380)
-     (Point 490 350)
-     (Point 542 350)
+     (Point 472 395)
+     (Point 480 395)
+     (Point 480 375)
+     (Point 490 375)
+     (Point 490 345)
+     (Point 542 345)
     )
     (connect D23:3 D1:1
-     (Point 472 430)
-     (Point 480 430)
-     (Point 480 420)
-     (Point 490 420)
-     (Point 490 390)
-     (Point 542 390)
+     (Point 472 425)
+     (Point 480 425)
+     (Point 480 415)
+     (Point 490 415)
+     (Point 490 385)
+     (Point 542 385)
     )
     (connect D23:9 D2:1
-     (Point 472 610)
-     (Point 490 610)
-     (Point 490 630)
-     (Point 542 630)
+     (Point 472 605)
+     (Point 490 605)
+     (Point 490 625)
+     (Point 542 625)
     )
     (connect D23:8 D3:1
-     (Point 472 580)
-     (Point 490 580)
-     (Point 490 590)
-     (Point 542 590)
+     (Point 472 575)
+     (Point 490 575)
+     (Point 490 585)
+     (Point 542 585)
     )
     (connect D23:7 D4:1
-     (Point 472 550)
-     (Point 542 550)
+     (Point 472 545)
+     (Point 542 545)
     )
     (connect D23:4 D5:1
-     (Point 472 460)
-     (Point 490 460)
-     (Point 490 430)
-     (Point 542 430)
+     (Point 472 455)
+     (Point 490 455)
+     (Point 490 425)
+     (Point 542 425)
     )
     (connect D23:5 D6:1
-     (Point 472 490)
-     (Point 490 490)
-     (Point 490 470)
-     (Point 542 470)
+     (Point 472 485)
+     (Point 490 485)
+     (Point 490 465)
+     (Point 542 465)
     )
     (connect D23:6 D7:1
-     (Point 472 520)
-     (Point 490 520)
-     (Point 490 510)
-     (Point 542 510)
+     (Point 472 515)
+     (Point 490 515)
+     (Point 490 505)
+     (Point 542 505)
     )
     (connect D23:1 D8:1
-     (Point 472 370)
-     (Point 480 370)
-     (Point 480 340)
-     (Point 490 340)
-     (Point 490 310)
-     (Point 542 310)
+     (Point 472 365)
+     (Point 480 365)
+     (Point 480 335)
+     (Point 490 335)
+     (Point 490 305)
+     (Point 542 305)
     )
-    (connect D17:0 D9:0
-     (Point 50 231)
-     (Point 50 359)
+    (connect D27:0 D9:0
+     (Point 120 225)
+     (Point 120 240)
+     (Point 50 240)
+     (Point 50 354)
     )
     (connect D18:0 D9:1
-     (Point 120 334)
-     (Point 120 340)
-     (Point 10 340)
-     (Point 10 380)
-     (Point 18 380)
+     (Point 120 329)
+     (Point 120 335)
+     (Point 10 335)
+     (Point 10 375)
+     (Point 18 375)
     )
     (connect D14:1 D10:1
-     (Point 835 270)
-     (Point 852 270)
+     (Point 835 265)
+     (Point 852 265)
     )
     (connect D10:0 D11:0
-     (Point 930 289)
-     (Point 930 304)
+     (Point 930 284)
+     (Point 930 299)
     )
     (connect D11:1 D12:1
-     (Point 1001 320)
-     (Point 1010 320)
-     (Point 1010 350)
-     (Point 870 350)
-     (Point 870 380)
-     (Point 888 380)
+     (Point 1001 315)
+     (Point 1010 315)
+     (Point 1010 345)
+     (Point 870 345)
+     (Point 870 375)
+     (Point 888 375)
     )
     (connect D12:1 D13:0
-     (Point 971 370)
-     (Point 990 370)
-     (Point 990 410)
-     (Point 930 410)
-     (Point 930 425)
+     (Point 971 365)
+     (Point 990 365)
+     (Point 990 405)
+     (Point 930 405)
+     (Point 930 420)
     )
     (connect D8:1 D14:1
-     (Point 657 300)
-     (Point 670 300)
-     (Point 670 230)
-     (Point 784 230)
+     (Point 657 295)
+     (Point 670 295)
+     (Point 670 225)
+     (Point 784 225)
     )
     (connect D0:1 D14:2
-     (Point 657 340)
-     (Point 680 340)
-     (Point 680 240)
-     (Point 784 240)
+     (Point 657 335)
+     (Point 680 335)
+     (Point 680 235)
+     (Point 784 235)
     )
     (connect D1:1 D14:3
-     (Point 657 380)
-     (Point 690 380)
-     (Point 690 250)
-     (Point 784 250)
+     (Point 657 375)
+     (Point 690 375)
+     (Point 690 245)
+     (Point 784 245)
     )
     (connect D5:1 D14:4
-     (Point 657 420)
-     (Point 700 420)
-     (Point 700 260)
-     (Point 784 260)
+     (Point 657 415)
+     (Point 700 415)
+     (Point 700 255)
+     (Point 784 255)
     )
     (connect D6:1 D14:5
-     (Point 657 460)
-     (Point 710 460)
-     (Point 710 270)
-     (Point 784 270)
+     (Point 657 455)
+     (Point 710 455)
+     (Point 710 265)
+     (Point 784 265)
     )
     (connect D7:1 D14:6
-     (Point 657 500)
-     (Point 740 500)
-     (Point 740 280)
-     (Point 784 280)
+     (Point 657 495)
+     (Point 740 495)
+     (Point 740 275)
+     (Point 784 275)
     )
     (connect D4:1 D14:7
-     (Point 657 540)
-     (Point 760 540)
-     (Point 760 290)
-     (Point 784 290)
+     (Point 657 535)
+     (Point 760 535)
+     (Point 760 285)
+     (Point 784 285)
     )
     (connect D3:1 D14:8
-     (Point 657 580)
-     (Point 770 580)
-     (Point 770 300)
-     (Point 784 300)
+     (Point 657 575)
+     (Point 770 575)
+     (Point 770 295)
+     (Point 784 295)
     )
     (connect D2:1 D14:9
-     (Point 657 620)
-     (Point 670 620)
-     (Point 670 630)
-     (Point 650 630)
-     (Point 650 690)
-     (Point 850 690)
-     (Point 850 630)
-     (Point 840 630)
-     (Point 840 610)
-     (Point 850 610)
-     (Point 850 350)
-     (Point 750 350)
-     (Point 750 310)
-     (Point 784 310)
+     (Point 657 615)
+     (Point 670 615)
+     (Point 670 625)
+     (Point 650 625)
+     (Point 650 685)
+     (Point 850 685)
+     (Point 850 625)
+     (Point 840 625)
+     (Point 840 605)
+     (Point 850 605)
+     (Point 850 345)
+     (Point 750 345)
+     (Point 750 305)
+     (Point 784 305)
     )
     (connect D8:2 D15:1
-     (Point 657 320)
-     (Point 670 320)
-     (Point 670 310)
-     (Point 650 310)
-     (Point 650 220)
-     (Point 770 220)
-     (Point 770 200)
-     (Point 840 200)
-     (Point 840 260)
-     (Point 830 260)
-     (Point 830 280)
-     (Point 840 280)
-     (Point 840 340)
-     (Point 780 340)
-     (Point 780 580)
-     (Point 794 580)
+     (Point 657 315)
+     (Point 670 315)
+     (Point 670 305)
+     (Point 650 305)
+     (Point 650 215)
+     (Point 770 215)
+     (Point 770 195)
+     (Point 840 195)
+     (Point 840 255)
+     (Point 830 255)
+     (Point 830 275)
+     (Point 840 275)
+     (Point 840 335)
+     (Point 780 335)
+     (Point 780 575)
+     (Point 794 575)
     )
     (connect D0:2 D15:2
-     (Point 657 360)
-     (Point 750 360)
-     (Point 750 590)
-     (Point 794 590)
+     (Point 657 355)
+     (Point 750 355)
+     (Point 750 585)
+     (Point 794 585)
     )
     (connect D1:2 D15:3
-     (Point 657 400)
-     (Point 730 400)
-     (Point 730 600)
-     (Point 794 600)
+     (Point 657 395)
+     (Point 730 395)
+     (Point 730 595)
+     (Point 794 595)
     )
     (connect D5:2 D15:4
-     (Point 657 440)
-     (Point 720 440)
-     (Point 720 610)
-     (Point 794 610)
+     (Point 657 435)
+     (Point 720 435)
+     (Point 720 605)
+     (Point 794 605)
     )
     (connect D6:2 D15:5
-     (Point 657 480)
-     (Point 710 480)
-     (Point 710 620)
-     (Point 794 620)
+     (Point 657 475)
+     (Point 710 475)
+     (Point 710 615)
+     (Point 794 615)
     )
     (connect D7:2 D15:6
-     (Point 657 520)
-     (Point 700 520)
-     (Point 700 630)
-     (Point 794 630)
+     (Point 657 515)
+     (Point 700 515)
+     (Point 700 625)
+     (Point 794 625)
     )
     (connect D4:2 D15:7
-     (Point 657 560)
-     (Point 690 560)
-     (Point 690 640)
-     (Point 794 640)
+     (Point 657 555)
+     (Point 690 555)
+     (Point 690 635)
+     (Point 794 635)
     )
     (connect D3:2 D15:8
-     (Point 657 600)
-     (Point 680 600)
-     (Point 680 650)
-     (Point 794 650)
+     (Point 657 595)
+     (Point 680 595)
+     (Point 680 645)
+     (Point 794 645)
     )
     (connect D2:2 D15:9
-     (Point 657 640)
-     (Point 670 640)
-     (Point 670 660)
-     (Point 794 660)
+     (Point 657 635)
+     (Point 670 635)
+     (Point 670 655)
+     (Point 794 655)
     )
     (connect D15:1 D16:1
-     (Point 845 620)
-     (Point 862 620)
+     (Point 845 615)
+     (Point 862 615)
     )
-    (connect D17:0 D18:0
-     (Point 50 231)
-     (Point 50 250)
-     (Point 120 250)
-     (Point 120 265)
+    (connect D27:0 D18:0
+     (Point 120 225)
+     (Point 120 260)
     )
     (connect D18:1 D20:0
-     (Point 177 300)
-     (Point 190 300)
-     (Point 190 350)
-     (Point 110 350)
-     (Point 110 507)
+     (Point 177 295)
+     (Point 190 295)
+     (Point 190 345)
+     (Point 110 345)
+     (Point 110 504)
     )
     (connect D9:1 D21:0
-     (Point 81 380)
-     (Point 100 380)
-     (Point 100 410)
-     (Point 50 410)
-     (Point 50 425)
+     (Point 81 375)
+     (Point 100 375)
+     (Point 100 405)
+     (Point 50 405)
+     (Point 50 420)
     )
     (connect D20:1 D22:1
-     (Point 203 580)
-     (Point 210 580)
-     (Point 210 560)
-     (Point 220 560)
-     (Point 220 490)
-     (Point 120 490)
-     (Point 120 410)
-     (Point 132 410)
+     (Point 203 575)
+     (Point 210 575)
+     (Point 210 555)
+     (Point 220 555)
+     (Point 220 485)
+     (Point 120 485)
+     (Point 120 405)
+     (Point 132 405)
     )
     (connect D22:1 D23:1
-     (Point 247 410)
-     (Point 257 410)
-     (Point 257 410)
-     (Point 267 410)
+     (Point 247 405)
+     (Point 267 405)
     )
     (connect D24:1 D23:2
-     (Point 176 650)
-     (Point 220 650)
-     (Point 220 570)
-     (Point 267 570)
+     (Point 176 645)
+     (Point 220 645)
+     (Point 220 565)
+     (Point 267 565)
     )
     (connect D20:0 D24:0
-     (Point 110 623)
-     (Point 110 629)
-     (Point 110 629)
-     (Point 110 635)
+     (Point 110 618)
+     (Point 110 630)
+    )
+    (connect D17:0 D26:0
+     (Point 110 121)
+     (Point 110 145)
+    )
+    (connect D26:1 D27:1
+     (Point 171 160)
+     (Point 190 160)
+     (Point 190 190)
+     (Point 50 190)
+     (Point 50 210)
+     (Point 62 210)
     )
    )
+   (stackingOrder 0 1 2 3 4 5 6 7 8 9
+     10 11 12 13 14 15 16 18 20 21
+     22 23 24 25 19 27 26 17)
   )
   (active panel)
   (active panel)
